.. meta::
   :google-site-verification: kxE4d_wW0ikuxlKuVCgIxNZT81VDOxKWJ7R9mbTnvKA



Electron Microscopy Machine Learning (EMicroML)
===============================================

``emicroml`` is a Python library for training machine learning models for
applications in microscopy.

The source code can be found in the `emicroml GitHub repository
<https://github.com/mrfitzpa/emicroml>`_.



Instructions for installing and uninstalling ``emicroml``
---------------------------------------------------------

For instructions on installing the ``emicroml`` library, see the
:ref:`installation_instructions_sec` page.


     
Learning how to use ``emicroml``
--------------------------------

For those new to the ``emicroml`` library, it is recommended that they take a
look at the :ref:`examples_sec` page, which contain code examples that show how
one can use the ``emicroml`` library. While going through the examples, readers
can consult the :ref:`reference_guide_sec` to understand what each line of code
is doing.



Reproducing data of preprints and published papers
--------------------------------------------------



Ultramicroscopy **283** (2026), 114347
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

The majority of the data presented in Ref. [Fitzpatrick1]_ can be reproduced by
running all of the examples listed on the page
:ref:`examples_modelling_cbed_distortion_estimation_sec`.



How to cite ``emicroml``
------------------------



Estimation of optical distortion in CBED patterns
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

If you are using machine learning models constructed via our ``emicroml``
library to estimate optical distortion in convergent beam electron diffraction
(CBED) patterns, please cite Ref. [Fitzpatrick1]_.


     
Contents
--------

.. toctree::
   :maxdepth: 6
   :numbered:

   Home <self>
   INSTALL
   Reference <_autosummary/emicroml>
   examples
   literature
   license


   
Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
